function yout=t_predic(tim,names,freq,tidecon,lat);
% T_PREDIC Tidal prediction
%      YOUT=T_PREDIC(TIM,NAMES,FREQ,TIDECON) makes
%      a tidal prediction using the output of T_TIDE
%      at the specified times TIM in decimal days
%      (from DATENUM).
%
%      In the simplest case, the tidal analysis was done
%      without nodal corrections, and thus neither will
%      then prediction.
%
%      If nodal corrections were used in the analysis,
%      then it is likely we will want to use them in
%      the prediction too. 
%      YOUT=T_PREDIC(TIM,NAMES,FREQ,TIDECON,LAT);
%      will compute and use these corrections for a latitude
%      LAT.

% R. Pawlowicz 8/11/99

if size(tidecon,2)==4,  % Real time series
  ap=tidecon(:,1)/2.*exp(-i*tidecon(:,3)*pi/180);
  am=conj(ap);
else
  ap=(tidecon(:,1)+tidecon(:,3))/2.*exp( i*pi/180*(tidecon(:,5)-tidecon(:,7)));
  am=(tidecon(:,1)-tidecon(:,3))/2.*exp( i*pi/180*(tidecon(:,5)+tidecon(:,7)));
end;

jdmid=mean(tim);
const=t_getconsts;
ju=zeros(size(freq));

% Check to make sure names and frequencies match expected values.
% (I suppose this is redundant)

for k=1:size(names,1),
  ju(k)=strmatch(names(k,:),const.name);
end;
if any(freq~=const.freq(ju)),
  error('Frequencies do not match names in input');
end;

% Get the astronical argument with or without nodal corrections.
if nargin==5,
  [v,u,f]=t_vuf(jdmid,ju,lat);
else
  [v,u,f]=t_vuf(jdmid,ju);
end;

ap=ap.*f.*exp(+i*2*pi*(u+v));
am=am.*f.*exp(-i*2*pi*(u+v));


tim=tim-jdmid;

[n,m]=size(tim);
tim=tim(:)';

yout=sum(exp( i*2*pi*freq*tim*24).*ap(:,ones(size(tim))))+ ...
     sum(exp(-i*2*pi*freq*tim*24).*am(:,ones(size(tim))));
     
yout=reshape(yout,n,m);

  
